@@ -6,5 +6,5 @@ router = APIRouter(prefix="/api/v1/echo", tags=["echo"])
 
 
 @router.get("")
-def get_echo(request: Request):
+def get_echo(request: Request) -> JSONResponse:
     return JSONResponse(content=jsonable_encoder(request.headers))
