@@ -631,7 +631,7 @@ class Auth:
                 MatGroupSummary(
                     matGroupId="mg-i6xu3cz5yznfp6twhlkwoixqpe",
                     matGroupName="Favorites",
-                    description="Favorite drinks, foods, series, games, and series",
+                    description="Favorite drinks, foods, books, and series",
                     hasUnfilled=True,
                 ),
             ]
@@ -659,21 +659,48 @@ class Auth:
                 reasons=[f"{ex}"],
             )
 
-    def put_favorite_drinks_eval_summary(
-        self, user_id: str, eval_id: str
+    def put_favorite_eval_summaries(
+        self, user_id: str, eval_eids: List[str]
     ) -> Union[PutObjectOutputTypeDef, CustomError]:
         try:
-            error_msg = f"Could not put favorite drinks eval summary: {user_id}"
+            error_msg = f"Could not put favorite eval summaries: {user_id}"
             favorite_drinks_eval = [
                 EvaluationSummary(
-                    evaluationId=eval_id,
+                    evaluationId=eval_eids[0],
                     evaluationName="Favorite Drinks",
                     matId="mat-7wby5o6exxce3md5yczyv26y5m",
                     status="unfilled",
                     createDate="2023-01-11",
                     dueDate="2023-09-30",
                     targetGroup="All",
-                )
+                ),
+                EvaluationSummary(
+                    evaluationId=eval_eids[1],
+                    evaluationName="Favorite Food",
+                    matId="mat-dnk5id4e46ndhxqoseerl2noqu",
+                    status="unfilled",
+                    createDate="2023-01-11",
+                    dueDate="2023-09-30",
+                    targetGroup="All",
+                ),
+                EvaluationSummary(
+                    evaluationId=eval_eids[2],
+                    evaluationName="Favorite Book Genres",
+                    matId="mat-jaidnlmkaxgalvplpyizmul52y",
+                    status="unfilled",
+                    createDate="2023-01-11",
+                    dueDate="2023-09-30",
+                    targetGroup="All",
+                ),
+                EvaluationSummary(
+                    evaluationId=eval_eids[3],
+                    evaluationName="Favorite Series",
+                    matId="mat-q7aekwxkh7252bejezpl2qsaiy",
+                    status="unfilled",
+                    createDate="2023-01-11",
+                    dueDate="2023-09-30",
+                    targetGroup="All",
+                ),
             ]
             evaluation_summaries = EvaluationSummaries.parse_obj(favorite_drinks_eval)
             s3_response = s3_put_object_bytes(
@@ -699,24 +726,24 @@ class Auth:
                 reasons=[f"{ex}"],
             )
 
-    def put_favorite_drinks_eval(
-        self, eval_id: str
+    def put_favorite_eval(
+        self, eval_id: str, eval_name: str, mat_id: str
     ) -> Union[PutObjectOutputTypeDef, CustomError]:
         try:
-            error_msg = f"Could not put favorite drinks eval: {eval_id}"
+            error_msg = f"Could not put favorite eval: {eval_name}"
 
-            favorite_drinks_eval = EmptyEvaluation(
+            favorite_eval = EmptyEvaluation(
                 evaluationId=eval_id,
-                evaluationName="Favorite Drinks",
-                matId="mat-7wby5o6exxce3md5yczyv26y5m",
+                evaluationName=eval_name,
+                matId=mat_id,
                 matGroupId="mg-i6xu3cz5yznfp6twhlkwoixqpe",
             )
 
             s3_response = s3_put_object_bytes(
                 Auth.clients.s3_client,
                 self.config.s3_bucket,
-                f"api/evals/mat-7wby5o6exxce3md5yczyv26y5m/unfilled/{eval_id}.json",
-                favorite_drinks_eval.json().encode("utf-8"),
+                f"api/evals/{mat_id}/unfilled/{eval_id}.json",
+                favorite_eval.json().encode("utf-8"),
             )
 
             if isinstance(s3_response, HttpError):
@@ -735,6 +762,46 @@ class Auth:
                 reasons=[f"{ex}"],
             )
 
+    def put_favorite_evals(
+        self, user_id: str, eval_eids: List[str]
+    ) -> Union[None, CustomError]:
+        try:
+            error_msg = f"Could not put favorite evals for {user_id}"
+
+            put_responses = [
+                self.put_favorite_eval(
+                    eval_eids[0], "Favorite Drinks", "mat-7wby5o6exxce3md5yczyv26y5m"
+                ),
+                self.put_favorite_eval(
+                    eval_eids[1], "Favorite Foods", "mat-dnk5id4e46ndhxqoseerl2noqu"
+                ),
+                self.put_favorite_eval(
+                    eval_eids[2],
+                    "Favorite Book Genres",
+                    "mat-jaidnlmkaxgalvplpyizmul52y",
+                ),
+                self.put_favorite_eval(
+                    eval_eids[3], "Favorite Series", "mat-q7aekwxkh7252bejezpl2qsaiy"
+                ),
+            ]
+
+            error_maybe = list(
+                filter(lambda x: isinstance(x, CustomError), put_responses)
+            )
+            if len(error_maybe) > 0:
+                LOG.error(error_maybe)
+                return CustomError(
+                    message=error_msg,
+                    reasons=error_maybe,
+                )
+
+        except Exception as ex:
+            LOG.error(error_msg)
+            return CustomError(
+                message=error_msg,
+                reasons=[f"{ex}"],
+            )
+
     def put_empty_eval_summaries(self, user_id: str) -> Union[None, CustomError]:
         try:
             error_msg = f"Could not put empty evaluation summaries: {user_id}"
@@ -772,7 +839,7 @@ class Auth:
             error_msg = f"Could not create user: {user_id}"
 
             s3_responses = []
-            fav_drinks_eval_id = get_eval_eid()
+            eval_eids = [get_eval_eid() for i in range(4)]
 
             user_email_and_id_response = self.put_user_email_and_id(
                 email_address, user_id, org_id
@@ -782,15 +849,13 @@ class Auth:
             mat_group_summaries_response = self.put_mat_group_summaries(user_id)
             s3_responses.append(mat_group_summaries_response)
 
-            favorite_drinks_eval_sum_repsponse = self.put_favorite_drinks_eval_summary(
-                user_id, fav_drinks_eval_id
+            favorite_eval_sums_repsponse = self.put_favorite_eval_summaries(
+                user_id, eval_eids
             )
-            s3_responses.append(favorite_drinks_eval_sum_repsponse)
+            s3_responses.append(favorite_eval_sums_repsponse)
 
-            favorite_drinks_eval_repsponse = self.put_favorite_drinks_eval(
-                fav_drinks_eval_id
-            )
-            s3_responses.append(favorite_drinks_eval_repsponse)
+            favorite_evals_repsponse = self.put_favorite_evals(user_id, eval_eids)
+            s3_responses.append(favorite_evals_repsponse)
 
             put_empty_evals_response = self.put_empty_eval_summaries(user_id)
             s3_responses.append(put_empty_evals_response)
